Miscellaneous routines
**********************

.. toctree::

.. currentmodule:: numpy

Buffer objects
--------------
.. autosummary::
   :toctree: generated/

   getbuffer
   newbuffer

Performance tuning
------------------
.. autosummary::
   :toctree: generated/

   alterdot
   restoredot
   setbufsize
   getbufsize
